@@ -69,7 +69,7 @@ const char *_vte_matcher_match(struct _vte_matcher *matcher,
 void _vte_matcher_print(struct _vte_matcher *matcher);
 
 /* Free a parameter array. */
-void _vte_matcher_free_params_array(GValueArray *params);
+void _vte_matcher_free_params_array(struct _vte_matcher *matcher, GValueArray *params);
 
 G_END_DECLS
 
